[GHC] #6000: Performance of Fibonnaci compare to Python
GHC
cvs-ghc at haskell.org
Thu Apr 12 05:05:06 CEST 2012
#6000: Performance of Fibonnaci compare to Python
-------------------------------------+--------------------------------------
Reporter: guest | Owner:
Type: bug | Status: new
Priority: normal | Component: Compiler
Version: 7.4.1 | Keywords: python, performance
Os: Linux | Architecture: x86_64 (amd64)
Failure: Runtime performance bug | Testcase:
Blockedby: | Blocking:
Related: |
-------------------------------------+--------------------------------------
Comment(by tibbe):
Replying to [comment:2 guest]:
> What's your architecture? I tried it with amd64. Also the python version
prints the out while the haskell version does not, can you try it again
after removing the print() statement from the python code?
I'm using a 32-bit GHC on a 64-bit machine (Core i7.) Removing the
printing from the Python code speeds it up a little bit:
{{{
$ time python pyfib.py
real 0m12.866s
user 0m12.841s
sys 0m0.022s
}}}
--
Ticket URL: <http://hackage.haskell.org/trac/ghc/ticket/6000#comment:3>
GHC <http://www.haskell.org/ghc/>
The Glasgow Haskell Compiler
More information about the Glasgow-haskell-bugs
mailing list